(overview)=
# Overview

The best way to learn how to use **League Manager** is to build something with it.

This tutorial is meant to show you how to use League Manager in conjunction with a _web framework_.

Each section is meant to explain a particular concept, and the difficulty increases as you move forward.

If you are already experienced, you can skip ahead to a specific topic to see usage examples. If you're just starting out, this can be a reference to come back to as you level up your Python skills.

(ready)=
## Ready?

The first section covers how to set up your Python coding environment. There are many other tutorials that cover this topic in depth, but hopefully there is enough here to get started.

Let's get to it!
